Package 'rk.dplyr'

Title: An RKWard plugin for data table combination and manipulation using the 'dplyr' library.
Description: An RKWard plugin for data table combination and manipulation using the 'dplyr' library.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.1.4
Built: 2026-06-05 07:07:01 UTC
Source: https://github.com/AlfCano/rk.dplyr

Help Index